summaryrefslogtreecommitdiffstats
path: root/plugin/simplestyle.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'plugin/simplestyle.cpp')
-rw-r--r--plugin/simplestyle.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/plugin/simplestyle.cpp b/plugin/simplestyle.cpp
index 84146d2..dc498be 100644
--- a/plugin/simplestyle.cpp
+++ b/plugin/simplestyle.cpp
@@ -149,10 +149,10 @@ Qt4TDEStyle::Qt4TDEStyle() : m_aboutData(NULL), m_tqApplication(NULL), m_tdeAppl
#ifdef INTEGRATE_WITH_TDE
if (!tqApp) {
// Initialize KApplication required data structures
int argc = 1;
char** argv;
// Supply it with fake data to keep KApplication happy
argv = (char**) malloc(sizeof(char*));
argv[0] = (char*) malloc(sizeof(char) * 19);
strncpy(argv[0], "Qt4TDEStyle", 19);
@@ -167,7 +167,7 @@ Qt4TDEStyle::Qt4TDEStyle() : m_aboutData(NULL), m_tqApplication(NULL), m_tdeAppl
// Qt4 can be SO STUPID sometimes...why can't I get the X11 display directly from qApp?!?!??
QWidget myhackedwidget;
- m_tdeApplication = new KApplication(myhackedwidget.x11Info().display());
+ m_tdeApplication = new TDEApplication(myhackedwidget.x11Info().display());
}
// Set the Qt4 icon set to the TDE icon set
@@ -149,10 +149,10 @@ Qt4TDEStyle::Qt4TDEStyle() : m_aboutData(NULL), m_tqApplication(NULL), m_tdeAppl
#ifdef INTEGRATE_WITH_TDE
if (!tqApp) {
- // Initialize KApplication required data structures
+ // Initialize TDEApplication required data structures
int argc = 1;
char** argv;
@@ -149,10 +149,10 @@ Qt4TDEStyle::Qt4TDEStyle() : m_aboutData(NULL), m_tqApplication(NULL), m_tdeAppl
int argc = 1;
char** argv;
- // Supply it with fake data to keep KApplication happy
+ // Supply it with fake data to keep TDEApplication happy
argv = (char**) malloc(sizeof(char*));
argv[0] = (char*) malloc(sizeof(char) * 19);